@@ -7,4 +7,6 @@ try:
 except ImportError:
     __version__ = "unknown"
 
-from .client import QoreClient
+from qore_client.client import QoreClient
+
+__all__ = ["QoreClient"]
